/**
	A neural network made up of a pair of mutually coupled neurons.
	@author Patrick D. Roberts, Neuro. Sci. Inst. OHSU, 04/01 (Supported by R01-MH60364) 
*/
import java.util.*;
import java.lang.Math;

 public class ELLNetwork extends Network{

	protected static final int MG1 = 0;
/*	protected static final int MG2 = 1;
	protected static final int LF = 2;
	protected static final int LG = 3;
*/	
	protected int cycleLength;
	private MormyridData data = new MormyridData();
	int holdThresh;
	
/**
	Initializes the network.
*/
  	public ELLNetwork(  ) {
		NUMNEURONS = 1;
//		module = new ELLModule( NUMNEURONS, 40 );  //  PF limit for mormyromast regions.
		module = new ELLModule( NUMNEURONS, 200 );
		module.setThreshold( MG1, 50 );
		module.setDiffPot( MG1, 0 );
//		module.setRefractory( MG1, 50 );  //  physiol refract
		module.setRefractory( MG1, 20 );
		((ELLModule) module).setNarrowThreshold( 65 );
		((ELLModule) module).setNarrowRefractory( MG1, 3 );
		module.setBaselinePot( MG1, data.GetMG2WaveformJLN( 7, 0) );
//		Waveform constWave = new Waveform( 200 );
//		constWave.setConstant( 1000 );
//		module.setBaselinePot( MG1, constWave );
/*		
		module.setThreshold( MG2, 70+1 );
		module.setThreshold( LF, 23 );
		module.setThreshold( LG, 23 );
		module.setDiffPot( MG2, 5 );
		module.setDiffPot( LF, 0 );
		module.setDiffPot( LG, 0 );
//		module.setRefractory( MG2, 50 );  //  physiol refract
		module.setRefractory( MG2, 20 );
		module.setRefractory( LF, 5 );
		module.setRefractory( LG, 5 );
		((ELLModule) module).setNarrowRefractory( MG2, 3 );
		
		module.setBaselinePot( MG2, data.GetMG2WaveformJLN( 5, 0) );
		module.setBaselinePot( LF, data.GetLFWaveformCD( 10, 0) );
		module.setBaselinePot( LG, data.GetLGWaveformCD( 0, 0) );
		constWave.setConstant( 1000+100 );
		module.setBaselinePot( MG2, constWave );
//		module.setBaselinePot( LF, constWave );
//		module.setBaselinePot( LG, constWave );
*/
		cycleLength = 200;
  	}

/**
	Initiates one time step of the network changing a parameter with each time step.
*/
  	public void StepNetwork( int time ) {
	  for (int i=0; i<NUMNEURONS; i++) {        
		module.serialInput( i, time%cycleLength );
	  }
/*======  B-spk gap  ======*/
		int deltaThreshMG1 = 0;//, deltaThreshMG2;
//		deltaThreshMG1 = (data.GetMG2WaveformJLN( 2, 0).getWavePt( time%cycleLength ))/30; // divide by 0.1*max
//		deltaThreshMG2 = (data.GetMG2WaveformJLN( 2, 0).getWavePt( time%cycleLength ) - 2000)/20;
//			module.setThreshold( MG1, deltaThreshMG1 + 50 );
//			module.setThreshold( MG2, deltaThreshMG2 + 71 );
/*=========================*/
		module.spikeINC( MG1, time );
		((ELLModule) module).spikeNarrow( MG1, ((ELLModule) module).getNarrowThreshold(), time );
//		module.setBaselinePot( MG1, data.GetMG2WaveformJLN( 20, 0) );
/*
//		module.spikeINC( MG2, time );
//		((ELLModule) module).spikeNarrow( MG2, ((ELLModule) module).getNarrowThreshold(), time );
		module.spikeNonPlastINC( LF );
		module.spikeNonPlastINC( LG );
		module.synapticConnect( MG1, MG2, -100 );
		module.synapticConnect( MG2, MG1, -100 );
		module.synapticConnect( MG1, LF, -1000 );
		module.synapticConnect( MG2, LG, -1000 );
		module.setBaselinePot( MG2, data.GetMG2WaveformJLN( 10, 0) );
*/
/*		if (time > 10*cycleLength && time < 90*cycleLength) 
			module.setBaselinePot( MG1, data.GetMG1WaveformJLN( 15, 0) );
		if (time > 10*cycleLength && time < 90*cycleLength) 
			module.setBaselinePot( MG2, data.GetMG2WaveformJLN( 7, 0) );*/ //Bump cancel.
// SS+JLN for cycles 20 -> 90
/*	if (time > 30*cycleLength && time < 90*cycleLength){
		module.setBaselinePot( MG1, data.GetMG1WaveformJLN( 20, 8) );
		module.setBaselinePot( MG2, data.GetMG2WaveformJLN( 10, 40) );
		}*/
  	}

/**
	Initiates one time step of the network changing a parameter with each trial.
*/
  	public void StepNetwork( int time, int trial ) {
	  for (int i=0; i<NUMNEURONS; i++) {        
//		module.poissonInput( i,  5 );
//		network.serialInput( i, time );
//		module.spikeINC( i );
//		module.synapticConnect( i, (i+1)%NUMNEURONS, 100*trial );	// Bi and Feldman setting
//		module.synapticConnect( i, (i+1)%NUMNEURONS, 1000*trial );  //Bell97 setting
	  }

  	}
/**
	Gets the present narrow spike of a neuron.
	@param neuronNum Which neuron.
*/
	public boolean getNarrowSpike( int neuronNum ) {
		return ((ELLModule) module).getNarrowSpike( neuronNum );
	}
}

class ELLModule extends Module{

	private boolean[] narrowSpike;
	private int nSpkThreshold;
	private int[] nSpkRefract;
	private int[] nSpkrefractCount;

/**
	Create a Module with numNeurons neurons plastic synaptic inputs following the [Bell97] rule.
*/
	public ELLModule( int numNeurons, int initNumInputSyns  ) {
		MormyridData data = new MormyridData();
		randomizer = new Random();
		funct = new HandyFuncts();
		Waveform wave = new Waveform();
//		epspWave = data.GetMG_EPSPWaveform( .01 ); // epsp size when combined with CD.
//		epspWave = data.GetMG_EPSPWaveform( .03 ); // epsp size for fixed point demonstration.
		epspWave = data.GetMG_EPSPWaveform( .02 );
		ipspWave = data.GetMG_EPSPWaveform( -.5 );
		ruleWaveF = data.GetMG_EPSPWaveform( -1 );
		ruleWaveB = new Waveform(1);
//		int nonassociative = 24; //demo speed
		int nonassociative = 12;
		noise = 10; thresh = 70;
		neuron = new Soma[numNeurons];
		narrowSpike = new boolean[numNeurons];
		for ( int num=0; num<numNeurons; num++ ) {
			neuron[num] = new Soma( noise, thresh );
			neuron[num].setEpsp( epspWave );
			neuron[num].setIpsp( ipspWave );
			neuron[num].setBias( 0 );
		}
		numInputSyns = initNumInputSyns;
		synapse = new PostSynapse[numNeurons][numInputSyns];
		for ( int i=0; i<numNeurons; i++ ) {
		  for ( int j=0; j<numInputSyns; j++ ) {
			if (i<2) {
				synapse[i][j] = new PostSynapse( (int) (6500+100*randomizer.nextGaussian()), 1, ruleWaveF, nonassociative   );
//				synapse[i][j] = new PostSynapse( (int) (2500*randomizer.nextFloat()), 1, ruleWaveF, nonassociative   );
//				synapse[i][j] = new PostSynapse( (int) (00*randomizer.nextFloat()), 1, ruleWaveF, nonassociative   );
				synapse[i][j].setRule( ruleWaveB, ruleWaveF, nonassociative  );
			}
			if (i>1)
				synapse[i][j] = new PostSynapse( (int) (500+500*randomizer.nextGaussian()), 1, ruleWaveF, nonassociative   );
		  }
		}
		preSpike = new boolean[numNeurons][numInputSyns];
		postSpike = new boolean[numNeurons];
		narrowSpike = new boolean[numNeurons];
		nSpkRefract = new int[numNeurons];
		nSpkrefractCount = new int[numNeurons];
	}

/** 
	Checks for a narrowSpike and adds it to a neuron in the Module.
	@param neuronNum Which neuron.
*/
	public void spikeNarrow( int neuronNum, int nThreshold, int time ) {
		narrowSpike[neuronNum] = false;
		if ( nSpkrefractCount[neuronNum] >= nSpkRefract[neuronNum] ) {
			if (neuron[neuronNum].getSpike( nThreshold )) {
				narrowSpike[neuronNum] = true;
				nSpkrefractCount[neuronNum] = 0;
			}
		}
		else nSpkrefractCount[neuronNum]++;
	}
/**
	Gets the narrow spike threshold at the present time step.
*/
  	public int getNarrowThreshold( ) {
		return nSpkThreshold;
  	}
/**
	Gets the membrane potential at the present time step.
*/
  	public void setNarrowThreshold( int newThreshold ) {
		nSpkThreshold =  newThreshold;
  	}
/**
	Sets the refractory period of the spike generator.
	@param newRefractory The refractory of the generator.
*/
  	public void setNarrowRefractory( int neuronNum, int newRefractory ) {
		nSpkRefract[neuronNum] = newRefractory;
		nSpkrefractCount[neuronNum] = nSpkRefract[neuronNum];
  	}
/**
	Gets the refractory of the spike generator.
*/
  	public int getNarrowRefractory( int neuronNum ) {
		return nSpkRefract[neuronNum];
  	}
/**
	Gets the present narrow spike of a neuron.
	@param neuronNum Which neuron.
*/
	public boolean getNarrowSpike( int neuronNum ) {
		return narrowSpike[neuronNum];
	}
/**
	Simple synaptic interaction between neurons in the Module.
	@param preNeuron Presynaptic neuron.
	@param postNeuron Postsynaptic neuron.
	@param strength Synaptic strength of connection (If strength>=0 => epsp, else ipsp).
*/
	public void synapticConnect( int preNeuron, int postNeuron, int strength ) {
		if ( strength >= 0 ) {
			if ( postSpike[preNeuron] || narrowSpike[preNeuron] ) neuron[postNeuron].epspInput( strength  );
		}
		else{
			if ( postSpike[preNeuron] || narrowSpike[preNeuron] ) neuron[postNeuron].ipspInput( -strength  ); 
		}
	}
}

