/**
	Data from Bell's lab from ELL cells in mormyrid electric fish (7/16/01).
	@author Patrick D. Roberts, Neuro. Sci. Inst. OHSU, 11/00 (Supported by R01-MH60364) 
*/
import java.util.*;

public class MormyridData {
//	protected static final int SHIFT = 2000;
	protected static final int SHIFT = 000;

	
/**
	Class constructor default.
*/
	public MormyridData() {
	}
/**
	Returns a waveform containing the sum of the CD+SS response of an MG1 cell.
*/
	public Waveform GetMG1WaveformCD( int scaleCD, int scaleSS ) {
		DataArrays arrayCD = new DataArrays();
		Waveform wave = new Waveform( arrayCD.mg1_cd.length );
		DataArrays arraySS = new DataArrays();
		for (int i=0; i<arrayCD.mg1_cd.length; i++){
			wave.setWavePt( scaleCD*arrayCD.mg1_cd[i] + scaleSS*arraySS.mg1_ss[i] + SHIFT, i );
		}
		return wave;
	}

/**
	Returns a waveform containing the sum of the CD+SS response of an MG2 cell.
*/
	public Waveform GetMG2WaveformCD( int scaleCD, int scaleSS ) {
		DataArrays arrayCD = new DataArrays();
		Waveform wave = new Waveform( arrayCD.mg2_cd.length );
		DataArrays arraySS = new DataArrays();
		for (int i=0; i<arrayCD.mg2_cd.length; i++){
			wave.setWavePt( scaleCD*arrayCD.mg2_cd[i] + scaleSS*arraySS.mg2_ss[i] + SHIFT, i );
		}
		return wave;
	}

/**
	Returns a waveform containing the sum of the CD+SS response of an LF cell.
*/
	public Waveform GetLFWaveformCD( int scaleCD, int scaleSS ) {
		DataArrays arrayCD = new DataArrays();
		Waveform wave = new Waveform( arrayCD.lf_cd.length );
		DataArrays arraySS = new DataArrays();
		for (int i=0; i<arrayCD.lf_cd.length; i++){
			wave.setWavePt( scaleCD*arrayCD.lf_cd[i] + scaleSS*arraySS.lf_ss[i] + SHIFT, i );
		}
		return wave;
	}

/**
	Returns a waveform containing the sum of the CD+SS response of an LG cell.
*/
	public Waveform GetLGWaveformCD( int scaleCD, int scaleSS ) {
		DataArrays arrayCD = new DataArrays();
		Waveform wave = new Waveform( arrayCD.lg_cd.length );
		DataArrays arraySS = new DataArrays();
		for (int i=0; i<arrayCD.lg_cd.length; i++){
			wave.setWavePt( scaleCD*arrayCD.lg_cd[i] + scaleSS*arraySS.lg_ss[i] + SHIFT, i );
		}
		return wave;
	}
/**
	Returns a waveform containing the sum of the JLN+SS response of an MG1 cell.
*/
	public Waveform GetMG1WaveformJLN( int scaleJLN, int scaleSS ) {
		DataArrays arrayJLN = new DataArrays();
		Waveform wave = new Waveform( arrayJLN.mg1_jln.length );
		DataArrays arraySS = new DataArrays();
		for (int i=0; i<arrayJLN.mg1_jln.length; i++){
			wave.setWavePt( scaleJLN*arrayJLN.mg1_jln[i] + scaleSS*arraySS.mg1_ss[i] + SHIFT, i );
		}
		return wave;
	}

/**
	Returns a waveform containing the sum of the JLN+SS response of an MG2 cell.
*/
	public Waveform GetMG2WaveformJLN( int scaleJLN, int scaleSS ) {
		DataArrays arrayJLN = new DataArrays();
		Waveform wave = new Waveform( arrayJLN.mg2_jln.length );
		DataArrays arraySS = new DataArrays();
		for (int i=0; i<arrayJLN.mg2_jln.length; i++){
			wave.setWavePt( scaleJLN*arrayJLN.mg2_jln[i] + scaleSS*arraySS.mg2_ss[i] + SHIFT, i );
		}
		return wave;
	}

/**
	Returns a waveform containing the sum of the JLN+SS response of an LF cell.
*/
	public Waveform GetLFWaveformJLN( int scaleJLN, int scaleSS ) {
		DataArrays arrayJLN = new DataArrays();
		Waveform wave = new Waveform( arrayJLN.lf_jln.length );
		DataArrays arraySS = new DataArrays();
		for (int i=0; i<arrayJLN.lf_jln.length; i++){
			wave.setWavePt( scaleJLN*arrayJLN.lf_jln[i] + scaleSS*arraySS.lf_ss[i] + SHIFT, i );
		}
		return wave;
	}

/**
	Returns a waveform containing the sum of the JLN+SS response of an LG cell.
*/
	public Waveform GetLGWaveformJLN( int scaleJLN, int scaleSS ) {
		DataArrays arrayJLN = new DataArrays();
		Waveform wave = new Waveform( arrayJLN.lg_jln.length );
		DataArrays arraySS = new DataArrays();
		for (int i=0; i<arrayJLN.lg_jln.length; i++){
			wave.setWavePt( scaleJLN*arrayJLN.lg_jln[i] + scaleSS*arraySS.lg_ss[i] + SHIFT, i );
		}
		return wave;
	}
/**
	Returns a waveform containing the epsp of an MG cell (scale = 0.2 is pretty smooth).
*/
	public Waveform GetMG_EPSPWaveform( double scale ) {
		DataArrays array = new DataArrays();
		int nonZeroLength = 1;
		for (int i=0; i<array.epsp_mg.length; i++){
			double val = array.epsp_mg[i]*scale;
			if ( 0 != (int) val ) nonZeroLength++;
		}
		Waveform wave = new Waveform( nonZeroLength );
		for (int i=0; i<nonZeroLength; i++){
			double point = array.epsp_mg[i]*scale;
			wave.setWavePt( (int) point, i );
		}
		return wave;
	}
/**
	Returns a waveform containing the epsp of an LG cell (scale = 0.3 is pretty smooth).
*/
	public Waveform GetLG_EPSPWaveform( double scale ) {
		DataArrays array = new DataArrays();
		int nonZeroLength = 1;
		for (int i=0; i<array.epsp_lg.length; i++){
			double val = array.epsp_lg[i]*scale;
			if ( 0 != (int) val ) nonZeroLength++;
		}
		Waveform wave = new Waveform( nonZeroLength );
		for (int i=0; i<nonZeroLength; i++){
			double point = array.epsp_lg[i]*scale;
			wave.setWavePt( (int) point, i );
		}
		return wave;
	}
}

class DataArrays {
public int[] mg1_cd = { // MG1_20100_16_JLN*
0,
0,
-1,
-1,
-1,
0,
1,
2,
3,
5,
7,
10,
13,
16,
19,
22,
26,
29,
33,
37,
40,
44,
49,
53,
57,
62,
67,
72,
77,
82,
87,
91,
96,
100,
104,
108,
111,
114,
116,
119,
120,
121,
122,
122,
122,
121,
120,
118,
116,
113,
110,
107,
103,
98,
93,
88,
82,
76,
70,
63,
57,
51,
45,
40,
36,
32,
28,
25,
22,
19,
16,
13,
10,
7,
3,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0};
public int[] mg1_ss = { // firstMG1*
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
-5,
-12,
-31,
-40,
-56,
-71,
-115,
-162,
-210,
-283,
-303,
-326,
-354,
-370,
-370,
-357,
-327,
-306,
-282,
-251,
-226,
-206,
-184,
-158,
-120,
-88,
-49,
-10,
12,
19,
26,
35,
44,
48,
51,
53,
53,
55,
56,
56,
56,
56,
56,
56,
56,
56,
56,
56,
54,
53,
53,
51,
48,
46,
44,
39,
35,
31,
27,
25,
21,
18,
18,
16,
14,
12,
10,
10,
8,
4,
1,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0};
public int[] mg2_cd = { // MG2_11399_08_JLN*
0,
1,
3,
5,
8,
10,
13,
15,
16,
16,
14,
11,
6,
0,
-7,
-13,
-19,
-23,
-26,
-26,
-22,
-16,
-6,
6,
21,
36,
52,
67,
80,
92,
102,
109,
113,
115,
115,
114,
111,
107,
103,
99,
96,
93,
90,
87,
85,
82,
80,
77,
75,
72,
69,
66,
63,
60,
57,
55,
53,
51,
49,
47,
46,
45,
43,
42,
41,
40,
39,
37,
36,
35,
33,
32,
31,
30,
29,
28,
27,
27,
26,
25,
25,
25,
25,
25,
24,
24,
23,
22,
21,
20,
19,
17,
15,
11,
6,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0};
public int[] mg2_ss = {  // MG2_11399_13*  (shifted +5 ms, 9/20/10)
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
10,
19,
27,
29,
28,
25,
21,
17,
12,
9,
7,
5,
4,
3,
2,
3,
3,
4,
5,
6,
7,
7,
7,
8,
8,
8,
8,
8,
8,
9,
9,
9,
9,
9,
9,
9,
9,
9,
8,
8,
8,
8,
7,
7,
7,
6,
6,
6,
5,
5,
5,
4,
4,
4,
3,
3,
3,
3,
3,
2,
2,
2,
2,
2,
2,
2,
1,
1,
1,
1,
1,
1,
1,
1,
1,
1,
1,
1,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0};
public int[] lf_cd = { // LF_011800_15_JLN*
0,
-3,
-6,
-11,
-17,
-23,
-29,
-35,
-42,
-50,
-59,
-71,
-85,
-101,
-118,
-137,
-155,
-172,
-188,
-200,
-208,
-210,
-206,
-198,
-184,
-168,
-150,
-130,
-109,
-89,
-69,
-51,
-35,
-20,
-8,
3,
11,
18,
22,
25,
26,
25,
23,
20,
17,
14,
11,
10,
9,
9,
8,
6,
5,
4,
3,
1,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0};
public int[] lf_ss = { // LF_20800_07*
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
1,
4,
12,
55,
127,
207,
255,
285,
295,
293,
290,
283,
272,
256,
240,
224,
203,
191,
178,
160,
146,
137,
122,
112,
98,
82,
73,
67,
60,
53,
47,
41,
36,
33,
30,
27,
24,
20,
14,
11,
7,
6,
4,
1,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0};
public int[] lg_cd = { // LG_80599_12_JLN*
0,
0,
1,
6,
10,
16,
23,
29,
35,
41,
48,
55,
61,
67,
72,
76,
80,
84,
88,
91,
95,
100,
104,
109,
114,
118,
121,
124,
125,
125,
124,
122,
119,
115,
112,
108,
105,
102,
99,
95,
91,
86,
81,
75,
70,
64,
58,
53,
48,
43,
39,
36,
35,
31,
29,
24,
18,
12,
5,
2,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0};
public int[] lg_ss = {  // firstLG*
0,
0,
0,
0,
0,
0,
0,
-5,
-12,
-21,
-32,
-45,
-86,
-128,
-241,
-325,
-376,
-418,
-448,
-478,
-512,
-545,
-582,
-606,
-617,
-617,
-609,
-591,
-561,
-528,
-475,
-427,
-379,
-344,
-315,
-277,
-245,
-210,
-182,
-160,
-135,
-120,
-104,
-87,
-73,
-59,
-44,
-32,
-23,
-15,
-8,
-3,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0};
public int[] mg1_jln = { // MG1_20100_16_JLN*
0,
0,
0,
0,
0,
-1,
-2,
-5,
-7,
-11,
-15,
-20,
-25,
-31,
-37,
-43,
-48,
-53,
-57,
-60,
-61,
-62,
-62,
-60,
-58,
-54,
-50,
-45,
-38,
-32,
-24,
-16,
-8,
1,
11,
20,
30,
39,
49,
58,
67,
76,
84,
92,
99,
106,
112,
117,
122,
126,
130,
133,
135,
137,
139,
139,
140,
140,
139,
138,
137,
136,
134,
132,
130,
128,
125,
123,
120,
118,
116,
113,
110,
108,
106,
103,
101,
99,
97,
95,
93,
88,
86,
84,
77,
74,
68,
64,
56,
52,
47,
36,
30,
25,
20,
18,
15,
10,
8,
5,
3,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0};
public int[] mg2_jln = { // MG2_11399_08_JLN*
0,
0,
0,
0,
0,
-1,
-1,
2,
5,
11,
18,
25,
31,
35,
37,
36,
33,
29,
24,
18,
14,
10,
8,
9,
12,
17,
24,
34,
46,
60,
75,
92,
110,
127,
144,
159,
173,
185,
194,
199,
201,
200,
195,
187,
177,
165,
152,
138,
125,
112,
99,
88,
77,
68,
61,
54,
49,
44,
39,
35,
32,
28,
25,
22,
20,
17,
15,
12,
10,
9,
7,
6,
5,
4,
4,
3,
3,
3,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0};
public int[] lf_jln = { // LF_011800_15_JLN*
0,
0,
0,
0,
0,
3,
5,
7,
6,
4,
1,
-4,
-10,
-16,
-21,
-25,
-27,
-28,
-27,
-26,
-23,
-20,
-15,
-11,
-6,
-1,
4,
9,
13,
17,
19,
21,
22,
22,
22,
21,
19,
18,
16,
14,
12,
9,
7,
5,
2,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0};
public int[] lg_jln = { // LG_80599_12_JLN*
0,
0,
0,
0,
0,
5,
10,
15,
20,
26,
31,
37,
42,
47,
51,
54,
56,
56,
56,
54,
51,
47,
43,
40,
37,
36,
35,
35,
34,
34,
32,
31,
29,
27,
26,
26,
26,
27,
29,
30,
32,
34,
36,
37,
37,
38,
37,
37,
37,
36,
35,
35,
33,
32,
30,
27,
24,
20,
16,
12,
8,
4,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0};
public int[] epsp_mg = {  // [Grant98]Fig11
0,
30,
66,
98,
132,
166,
195,
218,
231,
236,
235,
228,
220,
210,
199,
188,
177,
166,
155,
143,
132,
121,
111,
102,
93,
84,
77,
69,
62,
55,
48,
42,
37,
32,
27,
24,
21,
18,
15,
13,
11,
10,
8,
6,
5,
3,
2,
1,
0,
0};
public int[] epsp_lg = {  // [Grant98]Fig13
0,
10,
23,
35,
50,
66,
83,
100,
114,
124,
131,
134,
134,
132,
128,
124,
118,
112,
105,
98,
92,
86,
80,
74,
67,
60,
54,
48,
43,
38,
34,
30,
26,
22,
19,
15,
11,
8,
3,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0,
0};
}
