/**
	An array of long integers with periodic boundry conditions.
	@author Patrick D. Roberts, Neuro. Sci. Inst. OHSU, 11/00 (Supported by R01-MH60364) 
*/
import java.util.*;

public class SpikeGenerator {
	private Waveform probCurve;
	private int noise;
	private int threshold;
	private int potRange=10000;
  	private Random randomizer;
	
/**
	Class constructor default with noise=10 and threshold=50.
*/
	public SpikeGenerator() {
		noise = 10*10;
		threshold = 50*100;
		randomizer = new Random();
		probCurve = new Waveform( potRange );
		HandyFuncts funct = new HandyFuncts();
		for ( int i=-potRange/2; i<potRange/2; i++ ) probCurve.setWavePt( funct.Sigmoid(  i, noise ) , i );
	}
	
/**
	Class constructor that sets the noise level and threshold.
	@param initNoise The noise in the generator ( 0 < initNoise < 100 ).
	@param initThreshold The threshold of a spike ( 0 < initThreshold < 100 ).
*/
	public SpikeGenerator( int initNoise, int initThreshold ) {
		noise = initNoise*10;
		threshold = initThreshold*100;
		randomizer = new Random();
		probCurve = new Waveform( potRange );
		HandyFuncts funct = new HandyFuncts();
		for ( int i=-potRange/2; i<potRange/2; i++ ) probCurve.setWavePt( funct.Sigmoid(  i, noise ) , i );
	}
		
/**
	Sets the noise level of the spike generator.
	@param newNoise The noise in the generator ( 0 < noise < 100 ).
*/
  	public void setNoise( int newNoise  ) {
		noise = newNoise*10;
		probCurve = new Waveform( potRange );
		HandyFuncts funct = new HandyFuncts();
		for ( int i=-potRange/2; i<potRange/2; i++ ) probCurve.setWavePt( funct.Sigmoid(  i, noise ) , i );
  	}

/**
	Sets the threshold of the spike generator.
	@param newThreshold The threshold of the generator ( 0 < newThreshold < 100 ).
*/
  	public void setThreshold( int newThreshold ) {
		threshold = newThreshold*100;
  	}
/**
	Changes the sigmoid probability curve to a linear threshold in the spike generator.
*/
  	public void LinearProbCurve( ) {
		HandyFuncts funct = new HandyFuncts();
		for ( int i=-potRange/2; i<potRange/2; i++ ) probCurve.setWavePt( funct.LinearThreshold(  i, noise ) , i );
  	}
/**
	Gets the threshold of the spike generator.
*/
  	public int getThreshold( ) {
		return threshold/100;
  	}
  	
/**
	Returns TRUE if there is a spike generated by the membrane potential.
	@param memPot The membrane potential.
*/
  	public boolean getSpike( int memPot ) {
  		float ranFloat = 100*randomizer.nextFloat();
		int prob = getSpikeProb( memPot ); 
		if ( prob > ranFloat ) {
		return true;
		}
		else return false;
  	}
  	
/**
	Get the spike probability.
*/
  	public int getSpikeProb( int memPot ) {
  		if ( memPot-threshold >= potRange/2 ) return probCurve.getWavePt(potRange/2-1) ;
  		if ( memPot-threshold < -potRange/2 ) return probCurve.getWavePt(-potRange/2+1) ;
		return probCurve.getWavePt( memPot-threshold ) ; 
  	}

}

